export interface Props {
    /**
     * Имя графика
     */
    title?: string;
    /**
     * Иконка графика
     */
    gIcon?: string;
    /**
     * Цвет графика и иконки
     */
    color?: Color;
    /**
     * Список дат всех проверок (пример даты: 2020-01-01)
     */
    dates: string[];
    /**
     * Список значений параметра для каждой проверки (порядок соответсвует списку дат)
     */
    values: number[];
    /**
     * Список активных дат (пример даты: 2020-01-01)
     */
    activeDates: string[];
    /**
     * Индексы для получения значений из props.values.
     * Полученные значения используются для рассчета динамики изменения.
     * Если указан props.dynamic, то props.keysForDyn не используется в расчетах динамики.
     *
     * - start - индекс для получения значения в начале периода
     * - end - индекс для полученя значения в конце периода
     */
    keysForDyn: {
        start: number;
        end: number;
    };
    /**
     * Динамика
     */
    dynamic?: number;
    /**
     * Необходимо ли инвертировать значения ячеек графика
     */
    isInvert?: boolean;
    /**
     * Кол-во столбцов всего
     */
    numberCols?: number;
    /**
     * Html для футера
     */
    additionalHTML?: string;
    /**
     * Выбранная проверка (колонка)
     */
    modelValue?: Item | null;
    /**
     * Суффикс для значения
     */
    valueSuffix?: string;
    /**
     * Скрыть график на адаптиве
     *
     * - true - скрыть
     * - false - показать
     */
    hideChartInMobile?: boolean;
}
/**
 * Интерфейс проверки (используется для передачи данных о выбранной проверке через v-model)
 */
export interface Item {
    /**
     * Эл-т колонки выбранной проверки
     */
    elCol: HTMLElement;
    /**
     * Дата/время проверки
     */
    date?: string;
    /**
     * Значение параметра проверки
     */
    value?: string;
}
export declare const colors: {
    readonly blue: "blue";
    readonly orange: "orange";
    readonly pink: "pink";
};
export type Color = typeof colors[keyof typeof colors];
