import { Props as TopButtonProps } from '../../../forms/button/types';
export type Style = 'info' | 'success' | 'warning' | 'error' | 'alt';
export type Props = {
    /**
     * Уникальное id сообщения
     *
     * Для дедупликации вывода одного и того же сообщения
     *
     * Генерируется автоматически по входных данным
     */
    id: string;
    /**
     * Заголовок сообщения
     *
     * Можно передать html
     */
    title: string;
    /**
     * Текст сообщения
     *
     * Можно передать html
     */
    text: string;
    /**
     * Стиль отображения сообщения
     */
    style: Style;
    /**
     * Дополнительная информация, выводимая под сообщением
     *
     * Например, информация для админов
     */
    metaText?: string;
    /**
     * Произвольные props для вывода кнопки
     */
    buttonProps?: TopButtonProps & {
        default: string;
    };
    isSafeHTML?: boolean;
    /**
     * Установить стиль выделения сообщения
     */
    hightlight?: boolean;
    /**
     * Закрывать сообщение при клике по его кнопке или ссылке
     */
    selectToClose?: boolean;
    /**
     * Установить стиль закрытия сообщения
     *
     * Для удаления сообщения снаружи
     */
    forceClosed?: boolean;
};
export type Emits = {
    /**
     * Сообщение было закрыто
     */
    close: [];
};
