export interface Props {
    id: string;
    /**
     * Имя активной страницы
     */
    pageActive: string;
    /**
     * Базовая ширина окна
     */
    width?: string;
    /**
     * Базовая высота окна
     *
     * Установите auto, если окно должно подстраиваться под размеры содержимого
     *
     * Установите значение, если окно должно подстраиваться под размеры содержимого
     *
     * @example 'auto'
     * @example '200px'
     */
    height?: string;
    /**
     * Является ли окно модальным
     *
     * @see https://api.jqueryui.com/dialog/#option-modal
     */
    modal?: boolean;
    /**
     * Позиция окна
     *
     * @see https://api.jqueryui.com/dialog/#option-position
     */
    position?: string;
    /**
     * Для хеш-навигации
     */
    historyType?: 'push' | 'replace';
    /**
     * Список css классов для диалогового окна
     */
    classes?: string[];
}
export type Emits = {
    /**
     * Диалоговое окно было открыто
     */
    open: [pageName: string];
    /**
     * Диалоговое окно было закрыто
     */
    close: [pageName: string];
};
export interface Slots {
    /**
     * Слот с компонентами `TopDialogPage` и / или `TopDialogPageComponent`
     */
    default(props: {}): any;
}
