import { Size } from '../../forms/helpers';
export interface Props {
    /**
     * Выбранный элемент
     *
     * Массив выбранных элементов, если multiselect = true
     */
    modelValue: Item | Item[];
    /**
     * Список вариантов для выбора
     *
     * Работая совместно с apiRequest, всегда выводится перед результатами apiRequest
     */
    items?: Item[];
    /**
     * Режим выбора нескольких вариантов
     *
     * Константа, после установки менять нельзя
     */
    multiselect?: boolean;
    disabled?: boolean;
    size?: Size;
    isError?: boolean;
    /**
     * Если указан, будет выполнена загрузка результатов через API
     *
     * Константа, после установки заменять нельзя
     */
    apiRequest?: {
        params: {
            limit?: number;
            offset?: number;
            search?: string;
        };
        call: Function;
        cache: Map<string, {
            result: Array<Item>;
            nextOffset?: number;
        }>;
        [propName: string]: any;
    };
    /**
     * Минимальная длина для выполнения поиска
     *
     * Для apiRequest
     *
     * Константа, после установки менять нельзя
     */
    minLength?: number;
    /**
     * Использовать кэширвоание
     *
     * Для apiRequest
     *
     * Константа, после установки менять нельзя
     */
    useCache?: boolean;
    /**
     * Добавить в результаты item = {id:null, name:search}, где search - введенная строка в поле поиска
     */
    appendSearchToResult?: boolean;
    /**
     * Добавить вариант: "Все"
     *
     * Для multiselect = false
     */
    appendAllValue?: boolean;
    /**
     * Отобразить кнопку смены значения
     *
     * Работает с props.items без учета apiRequest
     *
     * Для multiselect = false
     */
    addChanger?: boolean;
    /**
     * Текст для placeholder поля поиска
     */
    placeholder?: string;
    /**
     * Выводить в placeholder поля поиска выбранное значение modelValue.name
     *
     * Для multiselect = false
     */
    showSelectedInInput?: boolean;
    /**
     * Выводить поле поиска
     */
    showSearch?: boolean;
}
export interface Slots {
    /**
     * Шаблон для генерации элементов списка результатов
     *
     * Принимает параметр item: Type
     *
     * Если шаблон не указан будет выводиться item.name
     *
     * Пример:
     *
     * ```html
     * <div :title="'id: ' + item.id">
     *     {{ item.name }}
     * </div>
     * ```
     */
    item?(props: {
        item: Item;
    }): any;
}
export interface PropsItemMulti {
    id: Item['id'];
    name: Item['name'];
}
export type EmitsItemMulti = {
    /**
     * Удалить выбранный элемент
     */
    delete: [id: Item['id']];
};
/**
 * Элемент, который можно выбрать в Selector
 */
export interface Item {
    /**
     * id объекта
     *
     * Если null - объект для добавления, не имеет свой id
     */
    id: number | null;
    name: string;
    [propName: string]: any;
}
export type { Size };
