export interface Props extends OpenerProps {
    /**
     * Уникальный id компонента, используется только в setup, т.е. изменение id будет проигнорировано
     *
     * Генерируется автоматически при создании кнопки Popup
     *
     * Можно задать вручную, если необходимо создать Popup без кнопки для последюущего использования,
     * особенно важно при создании большого числа кнопок, например в списках и таблицах
     */
    id?: string;
    /**
     * Класс, который нужно добавить к Popup, устанавилвается в момент открытия
     */
    class?: string;
    /**
     * Длительность анимации в мс
     */
    transitionDuration?: number;
    /**
     * Ссылка на справку.
     *
     * Если указана, кнопка справки будет добавлена в футере popup
     */
    footerSupportLink?: string;
}
export type PopupEvent = {
    elPopup: HTMLElement;
    elPopupOpener: HTMLElement;
};
export type Emits = {
    /**
     * Будет вызвано при открытии Popup
     */
    open: [popupEvent: PopupEvent];
    /**
     * Будет вызвано после закрытия Popup перед его удалением
     */
    close: [popupEvent: PopupEvent];
    /**
     * Будет вызвано при скролле списка в Popup
     */
    scrollContentList: [e: Event];
};
export interface OpenerProps {
    /**
     * id компонента Popup, который необходимо открыть
     */
    id: string;
    /**
     * Положение Popup относительно кнопки, которая его открывает
     *
     * - 0 - по коориднатам кнопки
     * - 1 - top
     * - 2 - right
     * - 3 - botton
     * - 4 - left
     */
    pos?: '0' | '1' | '2' | '3' | '4';
    /**
     * Добавить клювик
     */
    notch?: boolean;
    /**
     * Открывать / закрывать при наведении / отведении мыши
     */
    openByHover?: boolean;
    /**
     * Способ привязки позиционирования меню
     *
     * left/right - левый/правый край родителя
     *
     * fixed - по документу
     */
    posBy?: 'fixed' | 'left' | 'right';
}
export interface ListItemProps {
    /**
     * Тип элемента списка
     * * button - обычный кликабельный (выбираемый) элемент, поддерижвает вставку ссылок через атрибут href
     * * regular - произвольное содержимое
     * * title - заголовок
     * * delimiter - разделитель
     */
    type?: 'button' | 'regular' | 'title' | 'delimiter';
    /**
     * Следует ли закрывать меню по клику на элемент типа button и link
     */
    closeByClick?: boolean;
}
export declare const pos: {
    readonly 0: "0";
    readonly 1: "1";
    readonly 2: "2";
    readonly 3: "3";
    readonly 4: "4";
};
export declare const posBy: {
    readonly fixed: "fixed";
    readonly left: "left";
    readonly right: "right";
};
