/**
 * Работа с датами
 * @packageDocumentation
 */
/**
 * Получить день недели
 */
export declare const getDayOfWeek: (y: number, m: number, d: number) => string;
/**
 * Преобразовать дату в строку формата Y-m-d H:i:s
 * @param dateObject - объект Date
 * @param langFormat - если true, формат даты будет взят из Core.state.dateFormat
 * @param timeFormat - 0-только дата | 1-дата и часы | 2-дата и часы с минутами | 3-дата и часы с минутами и секундами
 */
export declare const dateToString: (dateObject: Date, langFormat?: boolean, timeFormat?: 0 | 1 | 2 | 3) => string;
/**
 * Получить объект Date из строки
 * @param date - строка с датой
 */
export declare function stringToDate(date: string): Date;
/**
 * Генерация даты-строки из миллисекунд (UTC), в формате Y-m-d H:i:s
 * @param timestamp - дата в мс, если не передана, берется дата на момент вызова функции
 * @param useFormat - если true, формат даты будет взят из Core.state.dateFormat
 * @param time
 * - 0: только дата
 * - 1: дата часы
 * - 2: дата и часы с минутами
 * - 3: дата и часы с минутами и секундами
 * - auto: часы и минуты будут выводиться только, если они не равны нулю
 */
export declare function genDate(timestamp: number | undefined, useFormat?: boolean, time?: 0 | 1 | 2 | 3 | 'auto'): string;
/**
 * Генерация даты-строки (время московское) из миллисекунд (UTC), в формате Y-m-d H:i:s
 * @param ms - дата в мс, если не передана, берется дата на момент вызова функции
 * @param langFormat - если true, формат даты будет взят из Core.state.dateFormat
 */
export declare function genDateMoscow(ms: number | undefined, useFormat?: boolean): string;
/**
 * Перевод даты в формат пользователя
 * @param dateMixed - объект даты или строка в формате Y-m-d H:i:s
 * @param time - 0-только дата | 1-дата и часы | 2-дата и часы с минутами | 3-дата и часы с минутами и секундами
 * @param dateFormat -
 * @param emptyValue - значение, которое надо вернуть, если дата не указана
 */
export declare function dateFormat(dateMixed: string | Date, time?: 0 | 1 | 2 | 3, dateFormat?: string, emptyValue?: string): string;
/**
 * Перевод даты из формата пользователя в системный формат Y-m-d H:i:s
 * @param date - строка с датой
 * @param emptyValue - значение, которое надо вернуть, если дата не указана
 */
export declare function dateUnformat(date: string, emptyValue?: string): string;
