/**
 * Работа с Document Object Model (DOM)
 * @packageDocumentation
 */
/**
 * Создать элемент
 * @param tagName
 * @param attrs - атрибуты
 * @param elsChildrens
 * @returns - созданный элемент
 */
export declare function genEl(tagName: string, attrs?: Record<string, string>, ...elsChildrens: HTMLElement[] | string[]): HTMLElement;
/**
 * Проверить видимость элемента
 * @param el
 * @returns - вернет true, если элемент считается видимым
 */
export declare function isVisible(el?: HTMLElement): boolean;
/**
 * Получить координаты элемента относительно документа
 * @param el
 * @returns - координаты элемента относительно документа
 */
export declare function offset(el: HTMLElement): {
    top: number;
    left: number;
};
/**
 * Получить значение css свойства элемента
 * @param el
 * @param property - имя свойства
 * @return - значение css стиля
 */
export declare function css(el: HTMLElement, property: string): string;
/**
 * Обернуть элемент и вернуть только что созданный элемент
 * @param el - элемент, который требуется обернуть
 * @param tagName - имя тега элемента, в который треубется обернуть элемент
 */
export declare function wrap(el: HTMLElement, tagName: string): HTMLElement;
/**
 * Найти и вернуть первый видимый элемент
 * @param el - корневой элемент поиска
 * @param selectors - см. параметр selectors в Document.querySelectorAll()
 */
export declare function querySelectorVisible(el: HTMLElement, selectors: string): HTMLElement | null;
/**
 * Найти и вернуть последний видимый элемент
 * @param el - корневой элемент поиска
 * @param selectors - см. параметр selectors в Document.querySelectorAll()
 */
export declare function querySelectorVisibleLast(el: HTMLElement, selectors: string): HTMLElement | null;
/**
 * Найти видимые элементы
 * @param el - корневой элемент поиска
 * @param selectors - см. параметр selectors в Document.querySelectorAll()
 */
export declare function querySelectorAllVisible(el: HTMLElement | Document, selectors: string): HTMLElement[];
/**
 * Найти элементы и вернуть в виде массива
 * @param el - корневой элемент поиска
 * @param selectors - см. параметр selectors в Document.querySelectorAll()
 */
export declare function querySelectorAllArray(el: HTMLElement | Document, selectors: string): HTMLElement[];
/**
 * Хранилище данных элемента
 * @param el
 * @param contextName - контекст, обычно используется имя компонента
 * @param contextData - установить объект с данными, предыдущие данные будут заменены, установите null для удаления данных
 * @returns - вернет объект контекста или undefined, если данные контекста не найдены
 */
export declare function storage(el?: HTMLElement & {
    topData?: any;
}, contextName?: string, contextData?: object | null | undefined): any | undefined;
/**
 * Очистить хранилище элемента
 */
export declare function storageClear(el?: HTMLElement & {
    topData?: any;
}): void;
declare const _default: {
    genEl: typeof genEl;
    isVisible: typeof isVisible;
    offset: typeof offset;
    css: typeof css;
    wrap: typeof wrap;
    querySelectorVisible: typeof querySelectorVisible;
    querySelectorVisibleLast: typeof querySelectorVisibleLast;
    querySelectorAllVisible: typeof querySelectorAllVisible;
    querySelectorAllArray: typeof querySelectorAllArray;
    storage: typeof storage;
    storageClear: typeof storageClear;
};
export default _default;
