/**
 * Работа со строками
 * @packageDocumentation
 */
/**
 * Сгенерировать числовой хэш от строки для идентификатора
 */
export declare const genIntHash: (string: string) => number;
/**
 * Проверить что переданная строка является URL
 */
export declare const isUrl: (url: string) => boolean;
/**
 * Добавляет пробелы между разрядами если требуется
 * @param nStr строка с числом
 */
export declare const addCommasWhite: (n: number | string) => string;
/**
 * Вставляет HTML-код разрыва строки перед каждым переводом строки
 */
export declare const nl2br: (str: string) => string;
/**
 * Перевести число без деситичной приставки в число с деситичной приставкой степеней тысячи (с параметрами по умолчанию 1255 -> '1.26 K')
 * @param number
 * @param precision - точность, количество знаков после запятой
 * @param dimension - размерность, по умолчанию 1000
 * @param suffix - суффикс к десятичной приставке (по умолчанию выводится латинская заглавная буква)
 */
export declare const numberWithWord: (number: number, precision?: number, dimension?: number, suffix?: string) => string;
/**
 * Обрезать текст под три точки
 * @param string
 * @param max_length - максимальное количество символов текста, остальное обрежеться
 * @param pos - область обрезки 0-начало | 1-середина | 2-конец строки
 */
export declare const ellipsis: (string: string, max_length: number, pos?: 0 | 1 | 2) => string;
/**
 * Сгенерировать строку текста для вывода количества в разном склонении
 * @param num
 * @param ending0 - родительный падеж, множ. число (10 модулей)
 * @param ending1 - именительный падеж, ед. число (1 модуль)
 * @param ending2 - винительный падеж, множ. число (3 модуля)
 */
export declare const numberEnding: (num: number, ending0: string, ending1: string, ending2: string) => string;
/**
 * Перевести строку в родительный падеж
 */
export declare const toRoditPadej: (str: string) => string;
/**
 * Транслитерация текста
 */
export declare const rusToLatin: (str: string) => string;
/**
 * Замена html-символов (`&`, `<`, `>`, `"`, `'`) на имена литер (`&` -> `&amp;`)
 */
export declare const htmlspecialchars: (str: string) => string;
/**
 * Выделить нужное в тексте желтым цветом
 * поиск происходит по строке fieldFilter.values[0]
 */
export declare const highlightHtml: (text: string, fieldFilter: {
    operator: "CONTAINS" | "REGEXP";
    values: string[];
}) => string;
/**
 * Пример: logHTTPCodesHundreds => log_http_codes_hundreds
 */
export declare const camelToSnakeCase: (str: string) => string | undefined;
/**
 * Получить url изображения флага, по коду страны по стандарту ISO 3166-1 alpha-2
 *
 * @todo Опубликовать в CDN или брать c публичного CDN
 */
export declare const genFlagLinkByCountryCode: (countryCode: string) => string;
/**
 * Обернуть все ссылки и email в тексте в html-тег `<a>`.
 *
 * Для email ставиться префикс `mailto:`
 */
export declare const addLinkTags: (text: string) => string;
/**
 * Перевести первую букву строки в верхний регистр
 */
export declare const toCapitalize: (str: string) => string;
/**
 * Получить случайную строку
 */
export declare const getRandomHash: (length?: number) => string;
